==> expyriment-0.10.0.tar.gz: expyriment-0.10.0/README.md <==
```
      ______                           _                          __ 
     / ____/_  __ ____   __  __ _____ (_)____ ___   ___   ____   / /_
    / __/  | |/_// __ \ / / / // ___// // __ `__ \ / _ \ / __ \ / __/
   / /___ _>  < / /_/ // /_/ // /   / // / / / / //  __// / / // /_  
  /_____//_/|_|/ .___/ \__, //_/   /_//_/ /_/ /_/ \___//_/ /_/ \__/  
              /_/     /____/                                         
```


Overview
========
**Expyriment** is an open-source and platform-independent lightweight Python
library for designing and conducting timing-critical behavioral and
neuroimaging experiments. The major goal is to provide a well-structured
Python library for script-based experiment development, with a high priority
being the readability of the resulting program code. Due to the availability
of an Android runtime environment, Expyriment is also suitable for the
development of experiments running on tablet PCs or smart-phones.

**Expyriment** has been tested extensively under Linux and Windows and is an
all-in-one solution, as it handles stimulus presentation, the recording of
input/output events, communication with other devices, and the collection and
preprocessing of data. Furthermore, it offers a hierarchical design structure,
which allows for an intuitive transition from the experimental design to a
running program. It is therefore also suited for students, as well as for
experimental psychologists and neuroscientists with little programming
experience.

- Project Homepage: http://www.expyriment.org

*GNU General Public License v3* (see [details])  
Florian Krause (florian@expyriment.org) & Oliver Lindemann (oliver@expyriment.org)

Documentation
=============
Documentation can be found in the directory "documentation".
For online documentation see: http://docs.expyriment.org

Examples
========
For online examples see: http://stash.expyriment.org/examples

Installation
============
The latest stable release of Expyriment can be found at Github:
https://github.com/expyriment/expyriment/releases/latest 
For detailed installation instructions, please see the online documentation: 
http://docs.expyriment.org/Installation.html

Reference
=========
Krause, F., & Lindemann, O. (2014). Expyriment: A Python library for cognitive 
and neuroscientific experiments. *Behavior Research Methods*, 46(2), 416-428. 
http://dx.doi.org/10.3758/s13428-013-0390-6

[details]: https://github.com/expyriment/expyriment/blob/master/COPYING.txt

==> expyriment-1.0.0.tar.gz: expyriment-1.0.0/README.md <==
```
      ______                           _                          __
     / ____/_  __ ____   __  __ _____ (_)____ ___   ___   ____   / /_
    / __/  | |/_// __ \ / / / // ___// // __ `__ \ / _ \ / __ \ / __/
   / /___ _>  < / /_/ // /_/ // /   / // / / / / //  __// / / // /_
  /_____//_/|_|/ .___/ \__, //_/   /_//_/ /_/ /_/ \___//_/ /_/ \__/
              /_/     /____/
```


Overview
========
**Expyriment** is an open-source and platform-independent lightweight Python
library for designing and conducting timing-critical behavioral and
neuroimaging experiments. The major goal is to provide a well-structured
Python library for script-based experiment development, with a high priority
being the readability of the resulting program code. Due to the availability
of an Android runtime environment, Expyriment is also suitable for the
development of experiments running on tablet PCs or smart-phones.

**Expyriment** has been tested extensively under Linux and Windows and is an
all-in-one solution, as it handles stimulus presentation, the recording of
input/output events, communication with other devices, and the collection and
preprocessing of data. Furthermore, it offers a hierarchical design structure,
which allows for an intuitive transition from the experimental design to a
running program. It is therefore also suited for students, as well as for
experimental psychologists and neuroscientists with little programming
experience.

- Project Homepage: https://expyriment.org

*GNU General Public License v3* (see [details])
Florian Krause (florian@expyriment.org) & Oliver Lindemann (oliver@expyriment.org)

Documentation
=============
Documentation can be found in the directory "documentation".
For online documentation see: https://docs.expyriment.org

Examples
========
For online examples see: https://github.com/expyriment/expyriment-stash/tree/master/examples

Installation
============
Expyriment can be installed via pip:

```bash
pip install expyriment
```

The latest stable release of Expyriment can be found at Github:
https://github.com/expyriment/expyriment/releases/latest

For detailed installation instructions, please see the online documentation:
https://docs.expyriment.org/Installation.html

Reference
=========
Krause, F., & Lindemann, O. (2014). Expyriment: A Python library for cognitive
and neuroscientific experiments. *Behavior Research Methods*, 46(2), 416-428.
https://doi.org/10.3758/s13428-013-0390-6

[details]: https://github.com/expyriment/expyriment/blob/master/COPYING.txt

Contributing
============
Join other
[contributors](https://github.com/expyriment/expyriment/graphs/contributors)
and help us out with Expyriment development! We are very happy to receive pull
requests on GitHub.
